@@ -188,9 +188,11 @@ def pydantic_model_creator(
     exclude_raw_fields: bool = bool(
         getattr(meta, "exclude_raw_fields", PydanticMeta.exclude_raw_fields)
     )
-    _sort_fields: bool = bool(
-        getattr(meta, "sort_alphabetically", PydanticMeta.sort_alphabetically)
-    ) if sort_alphabetically is None else sort_alphabetically
+    _sort_fields: bool = (
+        bool(getattr(meta, "sort_alphabetically", PydanticMeta.sort_alphabetically))
+        if sort_alphabetically is None
+        else sort_alphabetically
+    )
     _allow_cycles: bool = bool(
         getattr(meta, "allow_cycles", PydanticMeta.allow_cycles)
         if allow_cycles is None
@@ -303,7 +305,7 @@ def pydantic_model_creator(
             else:
                 pmodel = None
 
-            # If the result is None it has been exluded and we need to exclude the field
+            # If the result is None it has been excluded and we need to exclude the field
             if pmodel is None:
                 exclude += (fname,)
             else:
@@ -375,7 +377,7 @@ def pydantic_model_creator(
             pconfig.fields[fname] = fconfig
 
     # Here we endure that the name is unique, but complete objects are still labeled verbatim
-    if not has_submodel and exclude:
+    if not has_submodel:
         _name = name or f"{fqname}.leaf"
     elif has_submodel:
         _name = name or get_name()
