@@ -20,9 +20,9 @@ from tortoise.exceptions import ConfigurationError, NoValuesFetched, Operational
 from tortoise.fields.base import CASCADE, RESTRICT, SET_NULL, Field
 
 if TYPE_CHECKING:  # pragma: nocoverage
-    from tortoise.models import Model
-    from tortoise.queryset import QuerySet, Q
     from tortoise.backends.base.client import BaseDBAsyncClient
+    from tortoise.models import Model
+    from tortoise.queryset import Q, QuerySet
 
 MODEL = TypeVar("MODEL", bound="Model")
 
@@ -68,7 +68,11 @@ class ReverseRelation(Generic[MODEL]):
     """
 
     def __init__(
-        self, remote_model: Type[MODEL], relation_field: str, instance: "Model", from_field: str,
+        self,
+        remote_model: Type[MODEL],
+        relation_field: str,
+        instance: "Model",
+        from_field: str,
     ) -> None:
         self.remote_model = remote_model
         self.relation_field = relation_field
@@ -196,7 +200,8 @@ class ManyToManyRelation(ReverseRelation[MODEL]):
             .select(self.field.backward_key, self.field.forward_key)
         )
         query = db.query_class.into(through_table).columns(
-            through_table[self.field.forward_key], through_table[self.field.backward_key],
+            through_table[self.field.forward_key],
+            through_table[self.field.backward_key],
         )
 
         if len(instances) == 1:
@@ -377,6 +382,7 @@ class ManyToManyFieldInstance(RelationalField):
         forward_key: Optional[str] = None,
         backward_key: str = "",
         related_name: str = "",
+        on_delete: str = CASCADE,
         field_type: "Type[Model]" = None,  # type: ignore
         **kwargs: Any,
     ) -> None:
@@ -391,6 +397,7 @@ class ManyToManyFieldInstance(RelationalField):
         self.backward_key: str = backward_key
         self.through: str = through  # type: ignore
         self._generated: bool = False
+        self.on_delete = on_delete
 
 
 def OneToOneField(
@@ -497,6 +504,7 @@ def ManyToManyField(
     forward_key: Optional[str] = None,
     backward_key: str = "",
     related_name: str = "",
+    on_delete: str = CASCADE,
     db_constraint: bool = True,
     **kwargs: Any,
 ) -> "ManyToManyRelation":
@@ -528,6 +536,19 @@ def ManyToManyField(
     ``db_constraint``:
         Controls whether or not a constraint should be created in the database for this foreign key.
         The default is True, and that’s almost certainly what you want; setting this to False can be very bad for data integrity.
+    ``on_delete``:
+        One of:
+            ``field.CASCADE``:
+                Indicate that the model should be cascade deleted if related model gets deleted.
+            ``field.RESTRICT``:
+                Indicate that the related model delete will be restricted as long as a
+                foreign key points to it.
+            ``field.SET_NULL``:
+                Resets the field to NULL in case the related model gets deleted.
+                Can only be set if field has ``null=True`` set.
+            ``field.SET_DEFAULT``:
+                Resets the field to ``default`` value in case the related model gets deleted.
+                Can only be set is field has a ``default`` set.
     """
 
     return ManyToManyFieldInstance(  # type: ignore
@@ -536,6 +557,7 @@ def ManyToManyField(
         forward_key,
         backward_key,
         related_name,
+        on_delete=on_delete,
         db_constraint=db_constraint,
         **kwargs,
     )
